pub enum AuthError {
RequestError(Error),
MiddlewareError(Error),
ApiError(String),
UserNotFound,
SerializationError(Error),
TokenVerificationError(TokenVerificationError),
JwtError(Error),
InvalidPrivateKey,
ServiceAccountKeyRequired,
ImportUsersError(Vec<ImportUserError>),
}Expand description
Errors that can occur during Authentication operations.
Variants
RequestError(Error)
Wrapper for reqwest::Error.
MiddlewareError(Error)
Wrapper for reqwest_middleware::Error.
ApiError(String)
Errors returned by the Identity Toolkit API.
UserNotFound
The requested user was not found.
SerializationError(Error)
Wrapper for serde_json::Error.
TokenVerificationError(TokenVerificationError)
Error during ID token verification.
JwtError(Error)
Wrapper for jsonwebtoken::errors::Error.
InvalidPrivateKey
The private key provided in the service account is invalid.
ServiceAccountKeyRequired
A service account key is required for this operation (e.g., custom token signing) but was not provided.
ImportUsersError(Vec<ImportUserError>)
Errors occurred during a bulk import operation.