pub struct ActionCodeSettings {
pub url: String,
pub handle_code_in_app: Option<bool>,
pub ios: Option<IosSettings>,
pub android: Option<AndroidSettings>,
pub dynamic_link_domain: Option<String>,
}Expand description
Settings for generating email action links.
Fields
url: StringThe URL to continue to after the user clicks the link.
handle_code_in_app: Option<bool>Whether to open the link via a mobile app if installed.
ios: Option<IosSettings>iOS specific settings.
android: Option<AndroidSettings>Android specific settings.
dynamic_link_domain: Option<String>The dynamic link domain to use.