pub struct UserMetadata {
pub last_sign_in_time: Option<String>,
pub creation_time: Option<String>,
pub last_refresh_time: Option<String>,
}Expand description
Metadata associated with a user account.
Fields
last_sign_in_time: Option<String>The date and time the user last signed in.
creation_time: Option<String>The date and time the account was created.
last_refresh_time: Option<String>The date and time the user last refreshed their token.