FirebaseAuth

Struct FirebaseAuth 

pub struct FirebaseAuth { /* private fields */ }
Client for interacting with Firebase Authentication.

Implementations

Source

impl FirebaseAuth

pub fn new(middleware: AuthMiddleware) -> Self

Creates a new FirebaseAuth instance.

This is typically called via FirebaseApp::auth().

pub fn tenant_manager(&self) -> TenantAwareness

Returns the tenant awareness interface.

pub fn project_config_manager(&self) -> ProjectConfig

Returns the project config interface.

pub async fn verify_id_token( &self, token: &str, ) -> Result<FirebaseTokenClaims, AuthError>

Verifies a Firebase ID token.

This method fetches Google’s public keys (caching them respecting Cache-Control) and verifies the signature, audience, issuer, and expiration of the token.

Arguments
  • token - The JWT ID token string.

Creates a session cookie from an ID token.

Arguments
  • id_token - The ID token to exchange for a session cookie.
  • valid_duration - The duration for which the session cookie is valid.

Verifies a Firebase session cookie.

Arguments
  • session_cookie - The session cookie string.
pub fn create_custom_token( &self, uid: &str, custom_claims: Option<Map<String, Value>>, ) -> Result<String, AuthError>

Creates a custom token for the given UID with optional custom claims.

This token can be sent to a client application to sign in with signInWithCustomToken.

Arguments
  • uid - The unique identifier for the user.
  • custom_claims - Optional JSON object containing custom claims.

Generates a link for password reset.

Generates a link for email verification.

Generates a link for sign-in with email.

pub async fn import_users( &self, request: ImportUsersRequest, ) -> Result<ImportUsersResponse, AuthError>

Imports users in bulk.

Arguments
  • request - An ImportUsersRequest containing the list of users and hashing algorithm configuration.
pub async fn create_user( &self, request: CreateUserRequest, ) -> Result<UserRecord, AuthError>

Creates a new user.

pub async fn update_user( &self, request: UpdateUserRequest, ) -> Result<UserRecord, AuthError>

Updates an existing user.

pub async fn delete_user(&self, uid: &str) -> Result<(), AuthError>

Deletes a user by UID.

pub async fn get_user(&self, uid: &str) -> Result<UserRecord, AuthError>

Retrieves a user by their UID.

pub async fn get_user_by_email( &self, email: &str, ) -> Result<UserRecord, AuthError>

Retrieves a user by their email.

pub async fn get_user_by_phone_number( &self, phone: &str, ) -> Result<UserRecord, AuthError>

Retrieves a user by their phone number.

pub async fn list_users( &self, max_results: u32, page_token: Option<&str>, ) -> Result<ListUsersResponse, AuthError>

Lists users.

Arguments
  • max_results - The maximum number of users to return.
  • page_token - The next page token from a previous response.