Tenant

Struct Tenant 

pub struct Tenant {
Show 14 fields pub name: String, pub display_name: Option<String>, pub allow_password_signup: Option<bool>, pub enable_email_link_signin: Option<bool>, pub disable_auth: Option<bool>, pub enable_anonymous_user: Option<bool>, pub test_phone_numbers: Option<HashMap<String, String>>, pub mfa_config: Option<Value>, pub recaptcha_config: Option<Value>, pub sms_region_config: Option<Value>, pub monitoring: Option<Value>, pub password_policy_config: Option<Value>, pub email_privacy_config: Option<Value>, pub client: Option<Value>,
}
Represents a tenant in a multi-tenant project.

Fields

name: String

The resource name of the tenant. Format: “projects/{project-id}/tenants/{tenant-id}”

display_name: Option<String>

The display name of the tenant.

allow_password_signup: Option<bool>

Whether to allow email/password user authentication.

enable_email_link_signin: Option<bool>

Whether to enable email link user authentication.

disable_auth: Option<bool>

Whether authentication is disabled for the tenant.

enable_anonymous_user: Option<bool>

Whether to enable anonymous user authentication.

test_phone_numbers: Option<HashMap<String, String>>

Map of test phone numbers and their fake verification codes.

mfa_config: Option<Value>

The tenant-level configuration of MFA options.

recaptcha_config: Option<Value>

The tenant-level reCAPTCHA config.

sms_region_config: Option<Value>

Configures which regions are enabled for SMS verification.

monitoring: Option<Value>

Configuration related to monitoring project activity.

password_policy_config: Option<Value>

The tenant-level password policy config.

email_privacy_config: Option<Value>

Configuration for settings related to email privacy.

client: Option<Value>

Options related to how clients making requests on behalf of a project should be configured.