Module crashlytics

Module crashlytics 

Firebase Crashlytics module.

This module provides functionality for managing Crashlytics data. Currently, it supports deleting crash reports for a specific user, which is useful for privacy compliance (e.g., “Right to be Forgotten”).

Examples

let crashlytics = app.crashlytics();

// Delete crash reports for a user
let _ = crashlytics.delete_crash_reports("your-app-id", "user-uid").await;

Structs

FirebaseCrashlytics
Client for interacting with the Firebase Crashlytics API.

Enums

Error
Error type for Firebase Crashlytics operations.