pub struct FirebaseCrashlytics { /* private fields */ }Expand description
Client for interacting with the Firebase Crashlytics API.
Implementations
Sourceimpl FirebaseCrashlytics
impl FirebaseCrashlytics
Sourcepub fn new(middleware: AuthMiddleware) -> Self
pub fn new(middleware: AuthMiddleware) -> Self
Creates a new FirebaseCrashlytics client.
Sourcepub async fn delete_crash_reports(
&self,
app_id: &str,
user_id: &str,
) -> Result<(), Error>
pub async fn delete_crash_reports( &self, app_id: &str, user_id: &str, ) -> Result<(), Error>
Enqueues a request to permanently remove crash reports associated with the specified user.
Arguments
app_id- The App ID (e.g., the Google App ID, like1:1234567890:android:321abc456def7890).user_id- The unique identifier of the user whose crash reports should be deleted.
Errors
Returns an error if the request fails or if the API returns a non-success status code.