Module models

Module models 

Structs

ArrayValue
An array value.
BeginTransactionRequest
A request to begin a transaction.
BeginTransactionResponse
The response from beginning a transaction.
BitSequence
A sequence of bits.
BloomFilter
A Bloom filter.
CollectionSelector
A selection of a collection, such as messages as m1.
CommitRequest
A request to commit a transaction.
CommitResponse
The response from committing a transaction.
CompositeFilter
A filter that merges multiple other filters using the given operator.
Cursor
A position in a result set.
Document
Represents a Firestore document.
DocumentChange
A Document has changed.
DocumentDelete
A Document has been deleted.
DocumentMask
A set of field paths on a document.
DocumentRemove
A Document has been removed from the view of the targets.
DocumentTransform
A transformation of a document.
DocumentsTarget
A target specified by a set of document names.
ExistenceFilter
A Digest of documents that match the given target.
FieldFilter
A filter on a specific field.
FieldReference
A reference to a field.
FieldTransform
A transformation of a field of the document.
GeoPoint
An object representing a latitude/longitude pair.
ListCollectionIdsRequest
The request for listCollectionIds.
ListCollectionIdsResponse
The response for listCollectionIds.
ListDocumentsResponse
The response from listing documents.
ListenRequest
A request to listen to changes in documents.
ListenResponse
The response for ListenRequest.
MapValue
A map value.
Order
An order on a field.
Precondition
A precondition on a document, used for conditional writes.
Projection
The projection of document’s fields to return.
QueryFilter
A filter.
QueryTarget
A target specified by a query.
ReadOnlyOptions
Options for a read-only transaction.
ReadWriteOptions
Options for a read-write transaction.
RollbackRequest
A request to rollback a transaction.
RunQueryRequest
The request for runQuery.
RunQueryResponse
The response for runQuery.
Status
The RPC status.
StructuredQuery
A Firestore query.
Target
A specification of a set of documents to listen to.
TargetChange
Targets being watched have changed.
TransactionOptions
Options for a transaction.
UnaryFilter
A filter with a single operand.
Value
A message that can hold any of the supported value types.
Write
A write operation.
WriteResult
The result of a single write.

Enums

CompositeOperator
A composite operator.
Direction
A sort direction.
FieldOperator
A field filter operator.
FilterType
The type of filter.
TargetChangeType
The type of change.
TargetType
The type of target to listen to.
TransactionMode
The mode of a transaction.
TransformType
The type of transformation to apply.
UnaryOperator
A unary operator.
ValueType
The type of the value.
WriteOperation
The type of write operation.