pub struct CollectionSelector {
pub collection_id: String,
pub all_descendants: Option<bool>,
}Expand description
A selection of a collection, such as messages as m1.
Fields
collection_id: StringThe collection ID.
all_descendants: Option<bool>When false, selects only collections that are immediate children of
the parent specified in the containing RunQueryRequest.
When true, selects all descendant collections.