pub struct Cursor {
pub values: Vec<Value>,
pub before: Option<bool>,
}Expand description
A position in a result set.
Fields
values: Vec<Value>The values that represent the position, in the order they appear in the order by clause of a query.
before: Option<bool>If the position is just before or just after the given values.