pub struct DocumentDelete {
pub document: String,
pub removed_target_ids: Vec<i32>,
pub read_time: Option<String>,
}Expand description
A Document has been deleted.
Fields
document: StringThe resource name of the Document that was deleted.
removed_target_ids: Vec<i32>A set of target IDs for targets that previously matched this entity.
read_time: Option<String>The read timestamp at which the delete was observed.