pub struct DocumentRemove {
pub document: String,
pub removed_target_ids: Vec<i32>,
pub read_time: Option<String>,
}Expand description
A Document has been removed from the view of the targets.
Fields
document: StringThe resource name of the Document that has gone out of view.
removed_target_ids: Vec<i32>A set of target IDs for targets that previously matched this document.
read_time: Option<String>The read timestamp at which the remove was observed.