pub struct RunQueryResponse {
pub transaction: Option<String>,
pub document: Option<Document>,
pub read_time: Option<String>,
pub skipped_results: Option<i32>,
}Expand description
The response for runQuery.
Fields
transaction: Option<String>The transaction that was started or is being used.
document: Option<Document>A query result, not set when reporting partial progress.
read_time: Option<String>The time at which the document was read.
skipped_results: Option<i32>The number of results that have been skipped due to an offset between the last response and the current response.