pub struct StructuredQuery {
pub select: Option<Projection>,
pub from: Option<Vec<CollectionSelector>>,
pub where_clause: Option<QueryFilter>,
pub order_by: Option<Vec<Order>>,
pub start_at: Option<Cursor>,
pub end_at: Option<Cursor>,
pub offset: Option<i32>,
pub limit: Option<i32>,
}Expand description
A Firestore query.
Fields
select: Option<Projection>The projection to return.
from: Option<Vec<CollectionSelector>>The collections to query.
where_clause: Option<QueryFilter>The filter to apply.
order_by: Option<Vec<Order>>The order to apply to the query results.
start_at: Option<Cursor>A potential prefix of a position in the result set to start the query at.
end_at: Option<Cursor>A potential prefix of a position in the result set to end the query at.
offset: Option<i32>The number of results to skip.
limit: Option<i32>The maximum number of results to return.