pub struct Target {
pub target_type: Option<TargetType>,
pub resume_token: Option<String>,
pub read_time: Option<String>,
pub target_id: Option<i32>,
pub once: Option<bool>,
pub expected_count: Option<i32>,
}Expand description
A specification of a set of documents to listen to.
Fields
target_type: Option<TargetType>The type of target to listen to.
resume_token: Option<String>A resume token from a prior ListenResponse.
read_time: Option<String>Start listening after a specific read_time.
target_id: Option<i32>The target ID that identifies the target on the stream.
once: Option<bool>If the target should be removed once it is current and consistent.
expected_count: Option<i32>The number of documents that last matched the query at the resume token or read time.