pub struct TargetChange {
pub target_change_type: TargetChangeType,
pub target_ids: Vec<i32>,
pub cause: Option<Status>,
pub resume_token: Option<String>,
pub read_time: Option<String>,
}Expand description
Targets being watched have changed.
Fields
target_change_type: TargetChangeTypeThe type of change that occurred.
target_ids: Vec<i32>The target IDs of targets that have changed.
cause: Option<Status>The error that resulted in this change, if applicable.
resume_token: Option<String>A token that can be used to resume the stream for the given target_ids,
or all targets if target_ids is empty.
read_time: Option<String>The consistent read_time for the given target_ids.