pub struct Transaction {
pub transaction_id: String,
/* private fields */
}Expand description
Represents a Firestore Transaction.
Transactions provide a way to ensure that a set of reads and writes are executed atomically.
Fields
transaction_id: StringImplementations
Sourceimpl Transaction
impl Transaction
Sourcepub async fn get<T: DeserializeOwned>(
&self,
document_path: &str,
) -> Result<Option<T>, FirestoreError>
pub async fn get<T: DeserializeOwned>( &self, document_path: &str, ) -> Result<Option<T>, FirestoreError>
Reads the document at the given path.
The read is performed as part of the transaction.
Arguments
document_path- The path to the document to read.
Sourcepub fn set<T: Serialize>(
&self,
document_path: &str,
value: &T,
) -> Result<&Self, FirestoreError>
pub fn set<T: Serialize>( &self, document_path: &str, value: &T, ) -> Result<&Self, FirestoreError>
Overwrites the document referred to by document_path.
If the document does not exist, it will be created. If it does exist, it will be overwritten.
Arguments
document_path- The path to the document to write.value- The data to write.
Sourcepub fn update<T: Serialize>(
&self,
document_path: &str,
value: &T,
) -> Result<&Self, FirestoreError>
pub fn update<T: Serialize>( &self, document_path: &str, value: &T, ) -> Result<&Self, FirestoreError>
Updates fields in the document referred to by document_path.
If the document does not exist, the transaction will fail.
Arguments
document_path- The path to the document to update.value- The data to update.