Structs
- Android
Config - Android specific options for messages sent through FCM connection server.
- Android
FcmOptions - Options for features provided by the FCM SDK for Android.
- Android
Notification - Notification to send to android devices.
- Apns
Config - Apple Push Notification Service specific options.
- Apns
FcmOptions - Options for features provided by the FCM SDK for iOS.
- Apns
Payload - APNs payload.
- Aps
- The aps dictionary.
- ApsAlert
Dictionary - An alert dictionary.
- Batch
Response - Response from a batch send operation.
- Color
- Represents a color in the RGB color space.
- FcmOptions
- Template for FCM options across all platforms.
- Light
Settings - Settings to control the notification’s LED blinking rate and color.
- Message
- Represents a message to be sent via FCM.
- Multicast
Message - Represents a message to be sent to multiple recipients via FCM.
- Notification
- Basic notification template to use across all platforms.
- Send
Response - Response for an individual message in a batch.
- Topic
Management Error - Error details for a single registration token.
- Topic
Management Response - Response from the topic management APIs.
- Webpush
Config - Webpush protocol options.
- Webpush
FcmOptions - Options for features provided by the FCM SDK for Web.
Enums
- Android
Message Priority - Priority of a message to send to Android devices.
- ApsAlert
- An alert which can be a string or a dictionary.
- Notification
Priority - Priority levels for a notification.
- Visibility
- Visibility of the notification.