AndroidNotification

Struct AndroidNotification 

pub struct AndroidNotification {
Show 25 fields pub title: Option<String>, pub body: Option<String>, pub icon: Option<String>, pub color: Option<String>, pub sound: Option<String>, pub tag: Option<String>, pub click_action: Option<String>, pub body_loc_key: Option<String>, pub body_loc_args: Option<Vec<String>>, pub title_loc_key: Option<String>, pub title_loc_args: Option<Vec<String>>, pub channel_id: Option<String>, pub ticker: Option<String>, pub sticky: Option<bool>, pub event_time: Option<String>, pub local_only: Option<bool>, pub notification_priority: Option<NotificationPriority>, pub default_sound: Option<bool>, pub default_vibrate_timings: Option<bool>, pub default_light_settings: Option<bool>, pub vibrate_timings: Option<Vec<String>>, pub visibility: Option<Visibility>, pub notification_count: Option<i32>, pub light_settings: Option<LightSettings>, pub image: Option<String>,
}
Notification to send to android devices.

Fields

title: Option<String>

The notification’s title.

body: Option<String>

The notification’s body text.

icon: Option<String>

The notification’s icon.

color: Option<String>

The notification’s icon color, expressed in #rrggbb format.

sound: Option<String>

The sound to play when the device receives the notification.

tag: Option<String>

Identifier used to replace existing notifications in the notification drawer.

click_action: Option<String>

The action associated with a user click on the notification.

body_loc_key: Option<String>

The key to the body string in the app’s string resources.

body_loc_args: Option<Vec<String>>

Variable string values to be used in place of the format specifiers in body_loc_key.

title_loc_key: Option<String>

The key to the title string in the app’s string resources.

title_loc_args: Option<Vec<String>>

Variable string values to be used in place of the format specifiers in title_loc_key.

channel_id: Option<String>

The notification’s channel id.

ticker: Option<String>

Sets the “ticker” text, which is sent to accessibility services.

sticky: Option<bool>

When set to false or unset, the notification is automatically dismissed when the user clicks it in the panel.

event_time: Option<String>

Set the time that the event in the notification occurred. Notifications in the panel are sorted by this time.

local_only: Option<bool>

Set whether or not this notification is relevant only to the current device.

notification_priority: Option<NotificationPriority>

Set the relative priority for this notification.

default_sound: Option<bool>

If set to true, use the Android framework’s default sound for the notification.

default_vibrate_timings: Option<bool>

If set to true, use the Android framework’s default vibrate pattern for the notification.

default_light_settings: Option<bool>

If set to true, use the Android framework’s default LED light settings for the notification.

vibrate_timings: Option<Vec<String>>

Set the vibration pattern to use.

visibility: Option<Visibility>

Set the Notification.visibility of the notification.

notification_count: Option<i32>

Compute the count of the number of unread messages in your application’s launcher icon.

light_settings: Option<LightSettings>

Settings to control the notification’s LED blinking rate and color.

image: Option<String>

The URL of an image to be displayed in the notification.