pub struct ApsAlertDictionary {
pub title: Option<String>,
pub subtitle: Option<String>,
pub body: Option<String>,
pub loc_key: Option<String>,
pub loc_args: Option<Vec<String>>,
pub title_loc_key: Option<String>,
pub title_loc_args: Option<Vec<String>>,
pub subtitle_loc_key: Option<String>,
pub subtitle_loc_args: Option<Vec<String>>,
pub action_loc_key: Option<String>,
pub launch_image: Option<String>,
}Expand description
An alert dictionary.
Fields
title: Option<String>The title of the notification.
subtitle: Option<String>The subtitle of the notification.
body: Option<String>The body text of the notification.
loc_key: Option<String>The key to the body string in the app’s Localizable.strings file.
loc_args: Option<Vec<String>>Variable string values to appear in place of the format specifiers in loc_key.
title_loc_key: Option<String>The key to the title string in the app’s Localizable.strings file.
title_loc_args: Option<Vec<String>>Variable string values to appear in place of the format specifiers in title_loc_key.
subtitle_loc_key: Option<String>The key to the subtitle string in the app’s Localizable.strings file.
subtitle_loc_args: Option<Vec<String>>Variable string values to appear in place of the format specifiers in subtitle_loc_key.
action_loc_key: Option<String>The key to the label of the action button.
launch_image: Option<String>The filename of an image file in the app bundle.