pub struct MulticastMessage {
pub tokens: Vec<String>,
pub data: Option<HashMap<String, String>>,
pub notification: Option<Notification>,
pub android: Option<AndroidConfig>,
pub webpush: Option<WebpushConfig>,
pub apns: Option<ApnsConfig>,
pub fcm_options: Option<FcmOptions>,
}Expand description
Represents a message to be sent to multiple recipients via FCM.
Fields
tokens: Vec<String>A list of registration tokens to send the message to.
data: Option<HashMap<String, String>>Arbitrary key/value payload.
notification: Option<Notification>Basic notification template to use across all platforms.
android: Option<AndroidConfig>Android specific options for messages sent through FCM connection server.
webpush: Option<WebpushConfig>Webpush protocol options.
apns: Option<ApnsConfig>Apple Push Notification Service specific options.
fcm_options: Option<FcmOptions>Template for FCM options across all platforms.