Module remote_config

Module remote_config 

Firebase Remote Config module.

This module provides functionality to read and modify the Remote Config template.

Optimistic Concurrency

The publish method uses the ETag from the fetched configuration to ensure optimistic concurrency. If the remote configuration has changed since it was fetched, the publish operation will fail.

Modules

models

Structs

FirebaseRemoteConfig
Client for interacting with Firebase Remote Config.

Enums

Error
Errors that can occur during Remote Config operations.