pub struct RemoteConfig {
pub conditions: Vec<RemoteConfigCondition>,
pub parameters: HashMap<String, RemoteConfigParameter>,
pub parameter_groups: HashMap<String, RemoteConfigParameterGroup>,
pub etag: String,
pub version: Option<Version>,
}Expand description
Represents a Remote Config template.
Fields
conditions: Vec<RemoteConfigCondition>The list of named conditions.
parameters: HashMap<String, RemoteConfigParameter>The map of parameter keys to their optional default values and optional conditional values.
parameter_groups: HashMap<String, RemoteConfigParameterGroup>The map of parameter group names to their parameter group instances.
etag: StringThe ETag of the current template.
version: Option<Version>Version information for the template.