pub struct FirebaseStorage {
pub base_url: String,
pub project_id: String,
/* private fields */
}Expand description
Client for interacting with Cloud Storage for Firebase.
Fields
base_url: Stringproject_id: StringImplementations
Sourceimpl FirebaseStorage
impl FirebaseStorage
Sourcepub fn new(middleware: AuthMiddleware) -> Self
pub fn new(middleware: AuthMiddleware) -> Self
Creates a new FirebaseStorage instance.
This is typically called via FirebaseApp::storage().
Sourcepub fn bucket(&self, name: Option<&str>) -> Bucket
pub fn bucket(&self, name: Option<&str>) -> Bucket
Gets a Bucket instance that refers to the specific bucket.
Arguments
name- The name of the bucket (e.g. “my-project.appspot.com”). If not provided, it attempts to use the default bucket name derived from the project ID (e.g., “{project_id}.appspot.com”).