Structs
- Array
Value - An array value.
- Begin
Transaction Request - A request to begin a transaction.
- Begin
Transaction Response - The response from beginning a transaction.
- BitSequence
- A sequence of bits.
- Bloom
Filter - A Bloom filter.
- Collection
Selector - A selection of a collection, such as
messages as m1. - Commit
Request - A request to commit a transaction.
- Commit
Response - The response from committing a transaction.
- Composite
Filter - A filter that merges multiple other filters using the given operator.
- Cursor
- A position in a result set.
- Document
- Represents a Firestore document.
- Document
Change - A Document has changed.
- Document
Delete - A Document has been deleted.
- Document
Mask - A set of field paths on a document.
- Document
Remove - A Document has been removed from the view of the targets.
- Document
Transform - A transformation of a document.
- Documents
Target - A target specified by a set of document names.
- Existence
Filter - A Digest of documents that match the given target.
- Field
Filter - A filter on a specific field.
- Field
Reference - A reference to a field.
- Field
Transform - A transformation of a field of the document.
- GeoPoint
- An object representing a latitude/longitude pair.
- List
Collection IdsRequest - The request for
listCollectionIds. - List
Collection IdsResponse - The response for
listCollectionIds. - List
Documents Response - The response from listing documents.
- Listen
Request - A request to listen to changes in documents.
- Listen
Response - The response for
ListenRequest. - MapValue
- A map value.
- Order
- An order on a field.
- Precondition
- A precondition on a document, used for conditional writes.
- Projection
- The projection of document’s fields to return.
- Query
Filter - A filter.
- Query
Target - A target specified by a query.
- Read
Only Options - Options for a read-only transaction.
- Read
Write Options - Options for a read-write transaction.
- Rollback
Request - A request to rollback a transaction.
- RunQuery
Request - The request for
runQuery. - RunQuery
Response - The response for
runQuery. - Status
- The RPC status.
- Structured
Query - A Firestore query.
- Target
- A specification of a set of documents to listen to.
- Target
Change - Targets being watched have changed.
- Transaction
Options - Options for a transaction.
- Unary
Filter - A filter with a single operand.
- Value
- A message that can hold any of the supported value types.
- Write
- A write operation.
- Write
Result - The result of a single write.
Enums
- Composite
Operator - A composite operator.
- Direction
- A sort direction.
- Field
Operator - A field filter operator.
- Filter
Type - The type of filter.
- Target
Change Type - The type of change.
- Target
Type - The type of target to listen to.
- Transaction
Mode - The mode of a transaction.
- Transform
Type - The type of transformation to apply.
- Unary
Operator - A unary operator.
- Value
Type - The type of the value.
- Write
Operation - The type of write operation.