Module models

Module models 

Structs

AndroidConfig
Android specific options for messages sent through FCM connection server.
AndroidFcmOptions
Options for features provided by the FCM SDK for Android.
AndroidNotification
Notification to send to android devices.
ApnsConfig
Apple Push Notification Service specific options.
ApnsFcmOptions
Options for features provided by the FCM SDK for iOS.
ApnsPayload
APNs payload.
Aps
The aps dictionary.
ApsAlertDictionary
An alert dictionary.
BatchResponse
Response from a batch send operation.
Color
Represents a color in the RGB color space.
FcmOptions
Template for FCM options across all platforms.
LightSettings
Settings to control the notification’s LED blinking rate and color.
Message
Represents a message to be sent via FCM.
MulticastMessage
Represents a message to be sent to multiple recipients via FCM.
Notification
Basic notification template to use across all platforms.
SendResponse
Response for an individual message in a batch.
TopicManagementError
Error details for a single registration token.
TopicManagementResponse
Response from the topic management APIs.
WebpushConfig
Webpush protocol options.
WebpushFcmOptions
Options for features provided by the FCM SDK for Web.

Enums

AndroidMessagePriority
Priority of a message to send to Android devices.
ApsAlert
An alert which can be a string or a dictionary.
NotificationPriority
Priority levels for a notification.
Visibility
Visibility of the notification.