AndroidConfig

Struct AndroidConfig 

pub struct AndroidConfig {
    pub collapse_key: Option<String>,
    pub priority: Option<AndroidMessagePriority>,
    pub ttl: Option<String>,
    pub restricted_package_name: Option<String>,
    pub data: Option<HashMap<String, String>>,
    pub notification: Option<AndroidNotification>,
    pub fcm_options: Option<AndroidFcmOptions>,
    pub direct_boot_ok: Option<bool>,
}
Android specific options for messages sent through FCM connection server.

Fields

collapse_key: Option<String>

An identifier of a group of messages that can be collapsed, so that only the last message gets sent when delivery can be resumed.

priority: Option<AndroidMessagePriority>

Message priority. Can be “NORMAL” or “HIGH”.

ttl: Option<String>

How long (in seconds) the message should be kept in FCM storage if the device is offline.

restricted_package_name: Option<String>

Package name of the application where the registration token must match in order to receive the message.

data: Option<HashMap<String, String>>

Arbitrary key/value payload. If present, it will override google.firebase.fcm.v1.Message.data.

notification: Option<AndroidNotification>

Notification to send to android devices.

fcm_options: Option<AndroidFcmOptions>

Options for features provided by the FCM SDK for Android.

direct_boot_ok: Option<bool>

If set to true, messages will be allowed to be delivered to the app while the device is in direct boot mode.