Cloud Storage for Firebase module.
This module provides functionality for interacting with Google Cloud Storage buckets associated with your Firebase project. It supports uploading, downloading, and deleting files, as well as managing file metadata.
Examples
let storage = app.storage();
let bucket = storage.bucket(None); // Use default bucket
// Upload a file
let file_content = b"Hello, World!".to_vec();
let file = bucket.file("hello.txt");
let _ = file.save(file_content, "text/plain").await;Modules
Structs
- Firebase
Storage - Client for interacting with Cloud Storage for Firebase.
Enums
- Storage
Error - Errors that can occur during Storage operations.